==> common-1.3.0.33-sources.jar: cn/gtmap/gtc/workflow/clients/manage/TaskHandleClient.java <==
package cn.gtmap.gtc.workflow.clients.manage;

import cn.gtmap.gtc.workflow.domain.common.BaseResult;
import cn.gtmap.gtc.workflow.domain.common.ProcessOptResultDto;
import cn.gtmap.gtc.workflow.domain.manage.BackNodesDto;
import cn.gtmap.gtc.workflow.domain.manage.BackTaskDto;
import cn.gtmap.gtc.workflow.domain.manage.ForwardTaskDto;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author <a href="mailto:yuxinwang@gtmap.cn">yxw</a>
 * @version 1.0, 2018/7/11
 * @description 转发活动
 */

@FeignClient("${app.services.bpm-manage:bpm-manage}")
@RequestMapping("manage/v1")
public interface TaskHandleClient {

    /**
     * @param taskId
     * @return
     * @description 删除任务
     */
    @DeleteMapping(value = "/task-handel/{taskId}")
    boolean deleteTask(@PathVariable("taskId") String taskId);

    /**
     * @param processInstanceId 流程实例ID
     * @return
     * @description 根据流程实例id删除流程
     */
    @DeleteMapping(value = "/task-handel/process/{processInstanceId}")
    boolean deleteProcess(@PathVariable("processInstanceId") String processInstanceId);

    /**
     * @param processInstanceId 流程实例ID
     * @return
     * @description 根据流程实例id删除流程
     */
    @DeleteMapping(value = "/task-handel/process")
    boolean deleteProcessWithReason(@RequestParam("processInstanceId") String processInstanceId,
                                           @RequestParam(value = "reason", required = false) String reason );

    /**
     * 流程实例关闭(强制结束)
     * @param taskId
     */
    @PostMapping("/task-handel/{taskId}/finish")
    boolean processEndOfMandatory(@PathVariable("taskId") String taskId);

    /**
     * 流程实例废弃
     *
     * @param processInstanceId
     * @param deleteReason
     */
    @PostMapping("/task-handel/{processInstanceId}/task-discard")
    boolean taskAbandoned(@PathVariable("processInstanceId") String processInstanceId,
                                 @RequestParam(value = "deleteReason", required = false) String deleteReason);

    /**
     * 任务挂起
     *
     * @param processInstanceId
     */
    @PostMapping("/task-handel/{processInstanceId}/task-suspension")
    boolean taskHang(@PathVariable("processInstanceId") String processInstanceId,
                             @RequestParam(value = "reason", required = false) String reason);

    /**
     * 批量挂起
     *
     * @param processInsIds
     */
    @PostMapping("/task-handel/batch/task-suspension")
    List<ProcessOptResultDto> batchTaskHang(@RequestBody List<String> processInsIds,
                                                   @RequestParam(value = "reason", required = false) String reason);


    /**
     * 批量激活流程
     *
     * @param processInsIds
     */
    @PostMapping("/task-handel/batch/task-activate")
    List<ProcessOptResultDto> batchTaskActivation(@RequestBody List<String> processInsIds,
                                                         @RequestParam(value = "reason", required = false) String reason);

    /**
     * 任务激活
     *
     * @param processInstanceId
     */
    @PostMapping("/task-handel/{processInstanceId}/task-activate")
    boolean taskActivation(@PathVariable("processInstanceId") String processInstanceId,
                           @RequestParam(value = "reason", required = false) String reason);

    /**
     * 任务锁定
     *
     * @param taskId
     */
    @PostMapping(value = "/task-handel/{taskId}/locked")
    boolean taskLock(@PathVariable("taskId") String taskId, @RequestParam("username") String username);

    /**
     * 任务解除
     *
     * @param taskId
     */
    @PostMapping(value = "/task-handel/{taskId}/unlocked")
    boolean taskUnLock(@PathVariable("taskId") String taskId);

    /**
     * 任务委托与代理
     * @param username 用户名
     * @param taskId
     */
    @PostMapping("/task-handel/{taskId}/delegation")
    boolean taskDelegation(@PathVariable("taskId") String taskId, @RequestParam("username") String username);


    /**
     * 任务认领
     * @param username
     * @return
     */
    @PostMapping("/task-handel/claim")
    boolean taskClaim(@RequestParam("username") String username, @RequestBody List<String> taskIds);

    /**
     * @param taskId : 任务ID
     * @return
     * @description 执行转发前验证
     */
    @PostMapping(value = "/task-handel/forward/verify")
    BaseResult completeVerify(@RequestParam("taskId") String taskId);

    /**
     * @param forwardTaskDtos
     * @return
     * @description 执行转发活动任务
     */
    @PostMapping(value = "/task-handel/forward/complete")
    boolean complete(@RequestBody List<ForwardTaskDto> forwardTaskDtos);


    /**
     * @param
     * @return 自动转发办结
     */
    @PostMapping(value = "/task-handel/forward/auto-complete")
    boolean autoComplete(@RequestParam("processInstanceId") String processInstanceId,
                         @RequestParam("username") String username);

    /**
     * @param forwardTaskDto
     * @return
     * @description 办结活动任务
     */
    @PostMapping(value = "/task-handel/forward/end")
    boolean processEnd(@RequestBody ForwardTaskDto forwardTaskDto);

    /**
     * @param backTaskDtos
     * @return
     * @description 执行退回活动任务
     */
    @PostMapping(value = "/task-handel/back/complete")
    boolean back(List<BackTaskDto> backTaskDtos);

    @PostMapping(value = "/task-handel/back/to-first")
    boolean backToFirst(@RequestBody BackTaskDto backTaskDto);

    @PostMapping(value = "/task-handel/back/general")
    boolean backForGeneral(@RequestBody BackNodesDto backNodesDto);

    /**
     * @param taskIds 任务ID
     * @param opinion 意见
     * @param group 角色分组标识， organization: 撒选人员同组织下的角色  null: 所有角色
     * @return
     * @description
     */
    @PostMapping(value = "/task-handel/batch/forward/complete")
    List<ProcessOptResultDto> batchComplete(@RequestParam("taskIds") String taskIds,
                                                   @RequestParam(value = "opinion", required = false) String opinion,
                                                   @RequestParam(value = "group", required = false) String group);


    /**
     * @param taskId
     * @return
     * @description 执行取回活动任务
     */
    @PostMapping(value = "/task-handel/fetchBack/complete/{taskId}")
    boolean fetchBack(@PathVariable(name = "taskId")String taskId);


    @PostMapping("/task-handel/process/finish")
    boolean mandatoryFinishProcess(@RequestParam("processInsId") String processInsId,@RequestParam(value = "username", required = false) String username);

    /**
     * @param taskIds
     * @return
     * @description 批量取回流程
     */
    @PostMapping(value = "/task-handel/batch/fetch-back")
    List<ProcessOptResultDto> batchFetchBack(@RequestBody List<String> taskIds);

    /**
     * 批量退回流程
     * @param taskIds
     * @param opinion
     * @return
     */
    @PostMapping(value = "/task-handel/batch/back")
    List<ProcessOptResultDto> batchBack(@RequestBody List<String> taskIds,
                                               @RequestParam(value = "opinion", required = false) String opinion);

    /**
     * 批量取消认领流程
     * @param taskIds
     * @return
     */
    @PostMapping("/task-handel/batch/unclaim")
    List<ProcessOptResultDto> batchUnClaimTasks(@RequestBody List<String> taskIds);
}

==> common-1.3.0.39-sources.jar: cn/gtmap/gtc/workflow/clients/manage/TaskHandleClient.java <==
package cn.gtmap.gtc.workflow.clients.manage;

import cn.gtmap.gtc.workflow.domain.common.BaseResult;
import cn.gtmap.gtc.workflow.domain.common.ProcessOptResultDto;
import cn.gtmap.gtc.workflow.domain.manage.BackNodesDto;
import cn.gtmap.gtc.workflow.domain.manage.BackTaskDto;
import cn.gtmap.gtc.workflow.domain.manage.EventExtendDTO;
import cn.gtmap.gtc.workflow.domain.manage.ForwardTaskDto;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author <a href="mailto:yuxinwang@gtmap.cn">yxw</a>
 * @version 1.0, 2018/7/11
 * @description 转发活动
 */

@FeignClient("${app.services.bpm-manage:bpm-manage}")
@RequestMapping("manage/v1")
public interface TaskHandleClient {

    /**
     * @param taskId
     * @return
     * @description 删除任务
     */
    @DeleteMapping(value = "/task-handel/{taskId}")
    boolean deleteTask(@PathVariable("taskId") String taskId);

    /**
     * @param processInstanceId 流程实例ID
     * @return
     * @description 根据流程实例id删除流程 link deleteProcessWithReason()
     */
    @Deprecated
    @DeleteMapping(value = "/task-handel/process/{processInstanceId}")
    boolean deleteProcess(@PathVariable("processInstanceId") String processInstanceId);

    /**
     * @param processInstanceId 流程实例ID
     * @return
     * @description 根据流程实例id删除流程
     */
    @PostMapping(value = "/task-handel/process")
    boolean deleteProcessWithReason(@RequestParam("processInstanceId") String processInstanceId,
                                            @RequestParam(value = "reason", required = false) String reason,
                                            @RequestBody(required = false) EventExtendDTO eventExtendDTO);

    /**
     * 流程实例关闭(强制结束)
     * @param taskId
     */
    @PostMapping("/task-handel/{taskId}/finish")
    boolean processEndOfMandatory(@PathVariable("taskId") String taskId);

    /**
     * 流程实例废弃
     *
     * @param processInstanceId
     * @param deleteReason
     */
    @PostMapping("/task-handel/{processInstanceId}/task-discard")
    boolean taskAbandoned(@PathVariable("processInstanceId") String processInstanceId,
                                 @RequestParam(value = "deleteReason", required = false) String deleteReason);

    /**
     * 任务挂起
     *
     * @param processInstanceId
     */
    @PostMapping("/task-handel/{processInstanceId}/task-suspension")
    boolean taskHang(@PathVariable("processInstanceId") String processInstanceId,
                             @RequestParam(value = "reason", required = false) String reason);

    /**
     * 批量挂起
     *
     * @param processInsIds
     */
    @PostMapping("/task-handel/batch/task-suspension")
    List<ProcessOptResultDto> batchTaskHang(@RequestBody List<String> processInsIds,
                                                   @RequestParam(value = "reason", required = false) String reason);


    /**
     * 批量激活流程
     *
     * @param processInsIds
     */
    @PostMapping("/task-handel/batch/task-activate")
    List<ProcessOptResultDto> batchTaskActivation(@RequestBody List<String> processInsIds,
                                                         @RequestParam(value = "reason", required = false) String reason);

    /**
     * 任务激活
     *
     * @param processInstanceId
     */
    @PostMapping("/task-handel/{processInstanceId}/task-activate")
    boolean taskActivation(@PathVariable("processInstanceId") String processInstanceId,
                           @RequestParam(value = "reason", required = false) String reason);

    /**
     * 任务锁定
     *
     * @param taskId
     */
    @PostMapping(value = "/task-handel/{taskId}/locked")
    boolean taskLock(@PathVariable("taskId") String taskId, @RequestParam("username") String username);

    /**
     * 任务解除
     *
     * @param taskId
     */
    @PostMapping(value = "/task-handel/{taskId}/unlocked")
    boolean taskUnLock(@PathVariable("taskId") String taskId);

    /**
     * 任务委托与代理
     * @param username 用户名
     * @param taskId
     */
    @PostMapping("/task-handel/{taskId}/delegation")
    boolean taskDelegation(@PathVariable("taskId") String taskId, @RequestParam("username") String username);


    /**
     * 任务认领
     * @param username
     * @return
     */
    @PostMapping("/task-handel/claim")
    boolean taskClaim(@RequestParam("username") String username, @RequestBody List<String> taskIds);

    /**
     * @param taskId : 任务ID
     * @return
     * @description 执行转发前验证
     */
    @PostMapping(value = "/task-handel/forward/verify")
    BaseResult completeVerify(@RequestParam("taskId") String taskId);

    /**
     * @param forwardTaskDtos
     * @return
     * @description 执行转发活动任务
     */
    @PostMapping(value = "/task-handel/forward/complete")
    boolean complete(@RequestBody List<ForwardTaskDto> forwardTaskDtos);


    /**
     * @param
     * @return 自动转发办结
     */
    @PostMapping(value = "/task-handel/forward/auto-complete")
    boolean autoComplete(@RequestParam("processInstanceId") String processInstanceId,
                         @RequestParam("username") String username);

    /**
     * @param forwardTaskDto
     * @return
     * @description 办结活动任务
     */
    @PostMapping(value = "/task-handel/forward/end")
    boolean processEnd(@RequestBody ForwardTaskDto forwardTaskDto);

    /**
     * @param backTaskDtos
     * @return
     * @description 执行退回活动任务
     */
    @PostMapping(value = "/task-handel/back/complete")
    boolean back(List<BackTaskDto> backTaskDtos);

    @PostMapping(value = "/task-handel/back/to-first")
    boolean backToFirst(@RequestBody BackTaskDto backTaskDto);

    @PostMapping(value = "/task-handel/back/general")
    boolean backForGeneral(@RequestBody BackNodesDto backNodesDto);

    /**
     * @param taskIds 任务ID
     * @param opinion 意见
     * @param group 角色分组标识， organization: 撒选人员同组织下的角色  null: 所有角色
     * @return
     * @description
     */
    @PostMapping(value = "/task-handel/batch/forward/complete")
    List<ProcessOptResultDto> batchComplete(@RequestParam("taskIds") String taskIds,
                                                   @RequestParam(value = "opinion", required = false) String opinion,
                                                   @RequestParam(value = "group", required = false) String group);


    /**
     * @param taskId
     * @return
     * @description 执行取回活动任务
     */
    @PostMapping(value = "/task-handel/fetchBack/complete/{taskId}")
    boolean fetchBack(@PathVariable(name = "taskId")String taskId);


    @PostMapping("/task-handel/process/finish")
    boolean mandatoryFinishProcess(@RequestParam("processInsId") String processInsId,@RequestParam(value = "username", required = false) String username);

    /**
     * @param taskIds
     * @return
     * @description 批量取回流程
     */
    @PostMapping(value = "/task-handel/batch/fetch-back")
    List<ProcessOptResultDto> batchFetchBack(@RequestBody List<String> taskIds);

    /**
     * 批量退回流程
     * @param taskIds
     * @param opinion
     * @return
     */
    @PostMapping(value = "/task-handel/batch/back")
    List<ProcessOptResultDto> batchBack(@RequestBody List<String> taskIds,
                                               @RequestParam(value = "opinion", required = false) String opinion);

    /**
     * 批量取消认领流程
     * @param taskIds
     * @return
     */
    @PostMapping("/task-handel/batch/unclaim")
    List<ProcessOptResultDto> batchUnClaimTasks(@RequestBody List<String> taskIds);
}
